@@ -11,13 +11,14 @@ def info():
     vpc = get_instance_vpc(detail["instanceId"], detail["region"])
     instances = get_instances_from_vpc(vpc, detail["region"])
 
-    headers = ["Private IP", "Instance Name"]
+    headers = ["Private IP", "mssh command", "Instance Name"]
     table = []
     for reservation in instances['Reservations']:
         for instance in reservation['Instances']:
             private_ip_addr = instance['PrivateIpAddress']
             table.append([
                 private_ip_addr,
+                f'mssh {instance["InstanceId"]} -r {detail["region"]}',
                 [inst['Value'] for inst in instance['Tags']
                  if inst['Key'] == 'Name'][0]
             ])
